/*
write down your customized css style here
*/

/*评论计数*/
.para-comments-count:link,
.para-comments-count:visited {
    position: relative;
    /*float: left;*/
    min-width: 15px;
    height: 18px;
    padding: 0 3px;
    border: 1px solid #bbb;
    margin: 0 0 0 5px; 
    text-decoration: none;
    color: #333;
    background: #fff;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 3px;
}

.para-comments-count:hover,
.para-comments-count:focus,
.para-comments-count:active,
.para-comments-count:visited:hover,
.para-comments-count:visited:focus,
.para-comments-count:visited:active {
    text-decoration: underline;
    background-color: blue;
    color: white;
}

.para-comments-count.active {
background:green;
color:white;
}

/* The count tooltip. Not displayed in IE < 8 */

.para-comments-count:before,
.para-comments-count:after {
    content: "";
    position: absolute;
    top: 50%;
    right: -4px;
    width: 0
    height: 0;
    margin: -4px 0 0;
    border-width: 4px 0 4px 4px;
    border-style: solid;
    border-color: transparent #aaa;
}
.para-comments-count.right:before,
.para-comments-count.right:after {
right:auto;
left: -5px;
border-width: 4px 4px 4px 0px;
float:none;

}
.para-comments-count:after {
    right: -3px;
    border-left-color: #fff;
}
.para-comments-count.right:after {
    left: -4px;
    border-right-color: #fff;
}

.para-comments-count:hover:after {
    right: -3px;
    border-left-color: blue;
}
.para-comments-count.active:after {
    right: -3px;
    border-left-color: green;
}

.para-comments-count.right:hover:after {
    right:auto;
    left: -4px;
    border-right-color: blue;
}
.para-comments-count.active.right:after {
    right:auto;
    left: -4px;
    border-right-color: green;
}

.chapter-prev {position:absolute;left:10px;color:#ccc;-webkit-border-radius:4px;
-moz-border-radius:4px;
border-radius:4px;background-color:#eee;padding:4px 8px;
opacity:0.5;
filter:alpha(opacity=50);
}
.chapter-next {position:absolute;right:10px;color:#ccc;-webkit-border-radius:4px;
-moz-border-radius:4px;
border-radius:4px;background-color:#eee;padding:4px 8px;
opacity:0.5;
filter:alpha(opacity=50);
}
.chapter-prev a, .chapter-next a{color:#666;}
.chapter-top{top:8px;}
.chapter-down{bottom:5px;}

/* expander css */
.expander {position:absolute;top:5px;left:-17px;width:15px;height:100%;
font-size:20px;
background-color:transparent;
padding:2px;
cursor:pointer;
}
.expander div{height:23px;background-color:white;
border:1px solid #ccc;
border-left:none;
border-top-left-radius:5px;
-moz-border-radius-topleft:5px;
-webkit-border-top-left-radius:5px;
border-bottom-left-radius:5px;
-moz-border-radius-bottomleft:5px;
-webkit-border-bottom-left-radius:5px;
}
.expander div:hover{background-color:Khaki;}

.alert p {margin-bottom: 2px;}
#article div.outter, #index div.outter {position:relative;
-webkit-box-shadow:  0px 0px 4px 2px rgba(128, 128, 128, 0.5);
-moz-box-shadow:  0px 0px 4px 2px rgba(128, 128, 128, 0.5);
box-shadow:  0px 0px 4px 2px rgba(128, 128, 128, 0.5);
background-color: white;
margin-bottom:20px;
}
.outter-inner {padding:10px 20px 50px 20px;position:relative;}
.inline-tag {
background-color: blue;
color: white;
padding: 1px 4px 2px;
-webkit-border-radius: 3px;
-moz-border-radius: 3px;
border-radius: 3px;
cursor: pointer;
vertical-align: middle;
}

.footer {
margin-top: 5px;
padding: 15px;
}

body{font-family: "PT Serif",Georgia,Times,"Times New Roman",serif; font-size:1.2em;line-height:1.4em;}
li {line-height: 1.5em;}

#article .outter-inner{padding-top:30px;}

#markdown-content h2{
margin-bottom: 1em;
border-bottom: 1px solid #ddd;
}
#index h2{border-bottom: 1px solid #ddd;}
h1 {line-height:80px;}
dd {margin-left:30px;margin-top:5px;}

#index h2{border-bottom: 1px solid #ddd;}
#index ul.multiple, #index ul.multiple2, #index ul.multiple3 {
  *zoom: 1;
}

#index ul.multiple:before,
#index ul.multiple:after,
#index ul.multiple2:before,
#index ul.multiple2:after,
#index ul.multiple3:before,
#index ul.multiple3:after{
  display: table;
  line-height: 0;
  content: "";
}

#index ul.multiple:after,
#index ul.multiple2:after,
#index ul.multiple3:after{
  clear: both;
}
#index ul.multiple li,
#index ul.multiple2 li{float:left; width:48%;}
#index ul.multiple3 li{float:left; width:33%;}

#markdown-content .floatleft {margin:4px;float:left;clear:left;padding-right: 20px;}
#markdown-content .floatright {margin:4px;float:right;clear:right;padding-left: 20px;}
#markdown-content .floatcenter {margin:4px;text-align:center;}

#markdown-content h1, #wiki-content h2, #wiki-content h3, #wiki-content h4, 
#markdown-content h5, #wiki-content h6 {clear:both;}
#markdown-content .footnotes {margin-top:15px; padding-top:15px;border-top:2px solid #ddd;}

#markdown-content a.anchor, #index a.anchor {
    color: white;
    font-size: 1em;
    margin-left: 6px;
    padding: 0 4px 0 4px;
    text-decoration: none;
    border: none;
    background:none;
}
#markdown-content a.outter{
background: url(external-link-ltr-icon.png) center right no-repeat;
padding-right: 13px;
}

li > p {margin:0;}