#toc {
margin-top:15px;
color: #777;
overflow-y:auto;
background-color:white;
}

#toc ul {
margin: 0;
padding: 0;
list-style: none;
}

#toc li {
padding: 5px 10px;
}

#toc a {
color: black;
text-decoration: none;
display: block;
}

#toc li:hover {
background-color:#d1e5ee;
}

#toc .toc-h2 {
padding-left: 10px;
}

#toc .toc-h3 {
padding-left: 20px;
}

#toc .toc-active {
background: #336699;
text-shadow: none;
color: white;
}
#toc .toc-active a{
color:white;
}
