.table.table-header thead tr > th, .headtable{webkit-border-bottom-left-radius: 0px;
border-bottom-left-radius: 0px;
-moz-border-radius-bottomleft: 0px;
background-color: #FBFBFB;
background-image: -moz-linear-gradient(top,white,whiteSmoke);
background-image: -ms-linear-gradient(top,white,whiteSmoke);
background-image: -webkit-gradient(linear,0 0,0 100%,from(white),to(whiteSmoke));
background-image: -webkit-linear-gradient(top,white,whiteSmoke);
background-image: -o-linear-gradient(top,white,whiteSmoke);
background-image: linear-gradient(top,white,whiteSmoke);
background-repeat: repeat-x;
}
.table-bordered.table-header thead:last-child tr:last-child th:first-child, .table-bordered.table-header tbody:last-child tr:last-child td:first-child{webkit-border-bottom-left-radius: 0px;
border-bottom-left-radius: 0px;
-moz-border-radius-bottomleft: 0px;
}
.table-bordered.table-header thead:last-child tr:last-child th:last-child, .table-bordered.table-header tbody:last-child tr:last-child td:last-child{
-webkit-border-bottom-right-radius: 0px;
border-bottom-right-radius: 0px;
-moz-border-radius-bottomright: 0px;
}
.content-outter {
-webkit-box-shadow:  0px 0px 10px 5px rgba(128, 128, 128, 0.5);
-moz-box-shadow:  0px 0px 10px 5px rgba(128, 128, 128, 0.5);
box-shadow:  0px 0px 10px 5px rgba(128, 128, 128, 0.5);
}
html, body{
background-image:url(bg.gif);
font-size:13px;
}

.sidebar ul.simplemenu li{
font-size:14px;
}
/*.sidebar ul.simplemenu {
margin-left:-20px;
margin-right:-15px;
padding: 0px;
padding-bottom: 1px;
overflow: hidden;
}

.sidebar ul.simplemenu li{
line-height:20px;
font-size:14px;
background-color: #FBFBFB;
background-image: -moz-linear-gradient(top,white,whiteSmoke);
background-image: -ms-linear-gradient(top,white,whiteSmoke);
background-image: -webkit-gradient(linear,0 0,0 100%,from(white),to(whiteSmoke));
background-image: -webkit-linear-gradient(top,white,whiteSmoke);
background-image: -o-linear-gradient(top,white,whiteSmoke);
background-image: linear-gradient(top,white,whiteSmoke);
background-repeat: repeat-x;
}

.sidebar ul.simplemenu li a{
text-shadow: white 0 1px 1px;
}
*/

.required:after {
    content:'*';
    color: red;
}

/* panel */
.panel{
border: 1px solid #DEDEDE;
border-radius:3px;
-webkit-border-radius:3px;
-moz-border-radius:3px;
margin-top: 10px; 
margin-bottom: 10px ;
box-shadow: 0 0 10px rgba(189, 189, 189, 0.4);
-webkit-box-shadow: 0 0 10px rgba(189, 189, 189, 0.4);
-moz-box-shadow: 0 0 10px rgba(189, 189, 189, 0.4);
}

.panel form{margin-bottom:0px;}

.panel-header{
border:none;
padding-top:5px;
padding-left:5px;
border-bottom: 1px solid #DEDEDE;
border-radius:3px 3px 0 0;
-webkit-border-radius:3px 3px 0 0;
-moz-border-radius:3px 3px 0 0;
height:35px;
min-height:35px;
margin-bottom: 0;
font-weight:bold;
background: -moz-linear-gradient(top,  rgba(255,255,255,0) 0%, rgba(0,0,0,0.1) 100%);
background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,0)), color-stop(100%,rgba(0,0,0,0.1)));
background: -webkit-linear-gradient(top,  rgba(255,255,255,0) 0%,rgba(0,0,0,0.1) 100%);
background: -o-linear-gradient(top,  rgba(255,255,255,0) 0%,rgba(0,0,0,0.1) 100%);
background: -ms-linear-gradient(top,  rgba(255,255,255,0) 0%,rgba(0,0,0,0.1) 100%);
background: linear-gradient(to bottom,  rgba(255,255,255,0) 0%,rgba(0,0,0,0.1) 100%);
filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#00ffffff', endColorstr='#1a000000',GradientType=0 );

}

.panel-footer{
border:none;
padding:8px 5px 5px 15px;
border-top: 1px solid #DEDEDE;
border-radius:0 0 3px 3px;
-webkit-border-radius:0 0 3px 3px;
-moz-border-radius:0 0 3px 3px;
height:35px;
min-height:35px;
margin-bottom: 0;
font-weight:bold;
font-size:16px;
background-color:#DEDEDE;
vertical-align:middle;
}

.panel-content h2, .panel-content h3{
margin:5px 0px 10px 0px;
}
.panel-content h2.line, .panel-content h3.line{
border-bottom: 1px solid #ccc;
}
.panel-header h2{
font-size:15px;
width:auto;
clear:none;
float:left;
line-height:25px;
margin-top:2px;
}
.panel-header h3{
font-size:13px;
width:auto;
clear:none;
float:left;
line-height:25px;
}
.panel-header h2 > i{
margin-top:1px;
}
.panel-icon{
float:right;
}
.panel-icon a{
clear:none;
float:left;
margin:0 2px;
height: 18px;
margin-top: 2px;
line-height:25px;
}
.panel-icon a i{
margin-left:-4.5px;
}
.panel-content{
padding:10px;
}

.line {margin-bottom:10px;}
.separate {margin-bottom:10px;margin-top:10px;}
.shadow-line-top {border-top: solid 1px #fff;
-webkit-box-shadow: #999 0 -1px 0;
-moz-box-shadow: #999 0 -1px 0;
box-shadow: #999 0 -1px 0;
}
.shadow-line-bottom {border-bottom: solid 1px #999;
-webkit-box-shadow: #fff 0 1px 0;
-moz-box-shadow: #fff 0 1px 0;
box-shadow: #fff 0 1px 0;
}
.shadow-line-left {border-left: solid 1px #fff;
-webkit-box-shadow: #999 -1px 0 0;
-moz-box-shadow: #999 -1px 0 0;
box-shadow: #999 -1px 0 0;
}
.shadow-line-right {border-right: solid 1px #999;
-webkit-box-shadow: #fff 1px 0 0;
-moz-box-shadow: #fff 1px 0 0;
box-shadow: #fff 1px 0 0;
}

.user_info {line-height:40px;margin-bottom:0px;color:#555;text-shadow: 0 1px 0 white;}
.user_info a{color:#555;}

.pagination {margin-bottom: 5px;}
.pagination ul > li > a,
.pagination ul > li > span {
  padding: 0 6px;
  line-height: 28px;
  border-right: 1px solid rgba(0, 0, 0, 0.04);
  border-left: 1px solid rgba(255, 255, 255, 0.7);
  border-bottom: 1px solid #DADADA;
}

.pagination ul > .active > a,
.pagination ul > .active > span {
  color: #000;
  cursor: default;
  background-color: #dfdfdf;
  border-bottom: 1px solid #D26911;
}

.pagination ul > li:first-child > a,
.pagination ul > li:first-child > span {
  border-left: 1px solid #DADADA;
}

.pagination ul > li:last-child > a,
.pagination ul > li:last-child > span {
  border-right: 1px solid #DADADA;
}

.breadcrumb{
-webkit-box-shadow:  0px 2px 2px rgba(128, 128, 128, 0.5);
-moz-box-shadow:  0px 2px 2px rgba(128, 128, 128, 0.5);
box-shadow:  0px 2px 2px rgba(128, 128, 128, 0.5);
}

.sep-bullet:after{content:" • ";}
.gray, .gray a{color:gray;}
.lightgray, .lightgray a{color:lightgray;}
.darkgray, .darkgray a{color:darkgray;}
