#toc {
    margin-top:15px;
    position: fixed;
    background: whitesmoke;
    width: 21%;
    text-shadow: 0 1px 0 white;
    color: #777;
    overflow-y:auto;
    padding:8px;
    -webkit-box-shadow:  0px 0px 4px 2px rgba(128, 128, 128, 0.5);
    -moz-box-shadow:  0px 0px 4px 2px rgba(128, 128, 128, 0.5);
    box-shadow:  0px 0px 4px 2px rgba(128, 128, 128, 0.5);
}

#toc ul {
    margin: 0;
    padding: 0;
    list-style: none;
}

#toc li {
    padding: 5px 10px;
}

#toc a {
    color: black;
    text-decoration: none;
    display: block;
}

#toc .toc-h2 {
    padding-left: 10px;
}

#toc .toc-h3 {
    padding-left: 20px;
}

#toc .toc-active {
    background: #336699;
    text-shadow: none;
    color: white;
/*    box-shadow: inset -5px 0px 10px -5px #000;*/
}
#toc .toc-active a{
 color:white;
}
